pub enum SubClause<Id>{
Always,
HasAttrValue(Id, Attribute, AttrValue),
HasState(Id, State),
IsMounted(Id),
Not(Box<SubClause<Id>>),
And(Box<SubClause<Id>>, Box<SubClause<Id>>),
Or(Box<SubClause<Id>>, Box<SubClause<Id>>),
}Expand description
A subclause indicates the condition that must be satisfied in order to forward ev to target.
Usually clauses are single conditions, but there are also some special condition, to create “ligatures”, which are:
SubClause::Not: Negates inner conditionSubClause::And: the AND of the two clauses must betrueSubClause::Or: the OR of the two clauses must betrue
Variants
Always
Always forward event to component
HasAttrValue(Id, Attribute, AttrValue)
Forward event if target component has provided attribute with the provided value
If the attribute doesn’t exist on component, result is always false.
HasState(Id, State)
Forward event if target component has provided state
IsMounted(Id)
Forward event if target component is mounted
Not(Box<SubClause<Id>>)
Forward event if the inner clause is false
And(Box<SubClause<Id>>, Box<SubClause<Id>>)
Forward event if both the inner clauses are true
Or(Box<SubClause<Id>>, Box<SubClause<Id>>)
Forward event if at least one of the inner clauses is true
Implementations
sourceimpl<Id> SubClause<Id>
impl<Id> SubClause<Id>
sourcepub fn not(clause: Self) -> Self
pub fn not(clause: Self) -> Self
Shortcut for SubClause::Not without specifying Box::new(...)
sourcepub fn and(a: Self, b: Self) -> Self
pub fn and(a: Self, b: Self) -> Self
Shortcut for SubClause::And without specifying Box::new(...)
sourcepub fn or(a: Self, b: Self) -> Self
pub fn or(a: Self, b: Self) -> Self
Shortcut for SubClause::Or without specifying Box::new(...)