tuirealm::listener

Struct EventListenerCfg

source
pub struct EventListenerCfg<U>
where U: Eq + PartialEq + Clone + PartialOrd + Send,
{ /* private fields */ }
The event listener configurator is used to setup an event listener. Once you’re done with configuration just call EventListenerCfg::start and the event listener will start and the listener will be returned.

Implementations

source

impl<U> EventListenerCfg<U>
where U: Eq + PartialEq + Clone + PartialOrd + Send + 'static,

source

pub fn poll_timeout(self, timeout: Duration) -> Self

Set poll timeout. Poll timeout is the maximum time to wait when fetching the thread receiver.

Panics if timeout is 0

source

pub fn tick_interval(self, interval: Duration) -> Self

Defines the tick interval for the event listener. If an interval is defined, this will also enable the Tick event.

source

pub fn add_port( self, poll: Box<dyn Poll<U>>, interval: Duration, max_poll: usize, ) -> Self

Add a new Port (Poll, Interval) to the the event listener.

The interval is the amount of time between each Poll::poll call. The max_poll is the maximum amount of times the port should be polled in a single poll.

source

pub fn port(self, port: Port<U>) -> Self

Add a new Port to the the event listener

The Port needs to be manually constructed, unlike Self::add_port

source

pub fn crossterm_input_listener( self, interval: Duration, max_poll: usize, ) -> Self

Add to the event listener the default crossterm input listener crate::terminal::CrosstermInputListener

The interval is the amount of time between each Poll::poll call. The max_poll is the maximum amount of times the port should be polled in a single poll.

source

pub fn termion_input_listener(self, interval: Duration, max_poll: usize) -> Self

Add to the event listener the default termion input listener crate::terminal::TermionInputListener

The interval is the amount of time between each Poll::poll call. The max_poll is the maximum amount of times the port should be polled in a single poll.