pub struct Props { /* private fields */ }Expand description
The props struct holds all the attributes associated to the component. Properties have been designed to be versatile for all kind of components, but without introducing too many attributes at the same time.
Implementations
sourceimpl Props
impl Props