View

Struct View 

pub struct View<ComponentId, Msg, UserEvent>
where ComponentId: Eq + PartialEq + Clone + Hash, Msg: PartialEq, UserEvent: Eq + PartialEq + Clone,
{ /* private fields */ }
View is the wrapper and manager for all the components. A View is a container for all the components in a certain layout. Each View can have only one focused component at the time. At least one component must be always focused

Implementations

Source

impl<ComponentId, Msg, UserEvent> View<ComponentId, Msg, UserEvent>
where ComponentId: Eq + PartialEq + Clone + Hash, Msg: PartialEq + 'static, UserEvent: Eq + PartialEq + Clone + 'static,

pub fn mount( &mut self, id: &ComponentId, component: Box<dyn AppComponent<Msg, UserEvent>>, ) -> ViewResult<()>

Mount component on View. Returns error if the component is already mounted

pub fn umount(&mut self, id: &ComponentId) -> ViewResult<()>

Umount component from View

pub fn remount( &mut self, id: &ComponentId, component: Box<dyn AppComponent<Msg, UserEvent>>, ) -> ViewResult<()>

Remount component. This method WON’T change the focus stack

pub fn umount_all(&mut self)

Umount all components in the view and clear focus stack and state

pub fn mounted(&self, id: &ComponentId) -> bool

Returns whether component id is mounted

pub fn get_component( &self, id: &ComponentId, ) -> Option<&dyn AppComponent<Msg, UserEvent>>

Get a reference to the registered component for the given id, if there is one.

pub fn get_component_mut( &mut self, id: &ComponentId, ) -> Option<&mut dyn AppComponent<Msg, UserEvent>>

Get a mutable reference to the registered component for the given id, if there is one.

pub fn view(&mut self, id: &ComponentId, f: &mut Frame<'_>, area: Rect)

Render component called id

pub fn query<'a>( &'a self, id: &ComponentId, query: Attribute, ) -> ViewResult<Option<QueryResult<'a>>>

Query view component for a certain AttrValue Returns error if the component doesn’t exist Returns None if the attribute doesn’t exist.

pub fn attr( &mut self, id: &ComponentId, attr: Attribute, value: AttrValue, ) -> ViewResult<()>

Set attribute for component id Returns error if the component doesn’t exist

pub fn state(&self, id: &ComponentId) -> ViewResult<State>

Get state for component id. Returns Err if component doesn’t exist

pub fn active(&mut self, id: &ComponentId) -> ViewResult<()>

Shorthand for attr(id, Attribute::Focus(AttrValue::Flag(true))). It also sets the component as the current one having focus. Previous active component, if any, GETS PUSHED to the STACK Returns error: if component doesn’t exist. Use mounted() to check if component exists

NOTE: users should always use this function to give focus to components.

pub fn blur(&mut self) -> ViewResult<()>

Blur selected element AND DON’T PUSH CURRENT ACTIVE ELEMENT INTO THE STACK Shorthand for attr(id, Attribute::Focus(AttrValue::Flag(false))). It also unset the current focus and give it to the first element in stack. Returns error: if no component has focus

NOTE: users should always use this function to remove focus to components.

pub fn add_injector(&mut self, injector: Box<dyn Injector<ComponentId>>)

Add an injector to the view