pub trait AppComponent<Msg, UserEvent>: Component + Any{
// Required method
fn on(&mut self, ev: &Event<UserEvent>) -> Option<Msg>;
}Expand description
The app component describes the application level component, which is a wrapper around the Component,
which, in addition to all the methods exposed by the base component, it will handle the Events coming from the View.
The Event are passed to the on method, which will eventually return a Msg,
which is defined in your application as an enum.
In your application you should have a Component for each element on your UI, but the logic to implement
is very tiny, since the most of the work should already be done into the Component
and many of them are available in the standard library at tui-realm-stdlib.
Don’t forget you can find an example in the examples/ directory and you can discover many more information
about components in the repository documentation.